import { ICommandOptionDefinition, ICommandExampleDefinition } from "@zowe/imperative";
/**
 * Class to contain  constants
 * @export
 * @class Constants
 */
export declare class Constants {
    /**
     * Custom log location to prevent logging to default folder based on the package name
     * @static
     * @memberof Constants
     */
    static readonly LOG_LOCATION = "zowe/logs/zowe.log";
    /**
     * Display name
     * @static
     * @memberof Constants
     */
    static readonly DISPLAY_NAME = "Zowe CLI";
    /**
     * Binary executable name
     * @static
     * @memberof Constants
     */
    static readonly BINARY_NAME = "zowe";
    /**
     *
     * Documentation link for the CLI
     * @static
     * @memberof Constants
     */
    static readonly DOCUMENTATION_LINK = "https://docs.zowe.org";
    /**
     *
     * Support link for zowe
     * @static
     * @memberof Constants
     */
    static readonly SUPPORT_LINK = "https://www.zowe.org";
    /**
     * Description of product
     * @static
     * @memberof Constants
     */
    static readonly DESCRIPTION: string;
    /**
     * Home environment variable
     * @static
     * @memberof Constants
     */
    static readonly HOME_ENV_KEY = "ZOWE_CLI_HOME";
    /**
     * Prefix for environmental variable settings used by Imperative
     * @static
     * @memberof Constants
     */
    static readonly ENV_PREFIX = "ZOWE";
    /**
     * Home directory
     * @static
     * @memberof Constants
     */
    static readonly HOME_DIR = "~/.zowe";
    static BASE_CONNECTION_OPTION_GROUP: string;
    /**
     * Option used in profile creation and commands for hostname
     */
    static BASE_OPTION_HOST: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for port
     */
    static BASE_OPTION_PORT: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for username / ID
     */
    static BASE_OPTION_USER: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for password/passphrase
     */
    static BASE_OPTION_PASSWORD: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for rejectUnauthorized setting for connecting to z/OSMF
     */
    static BASE_OPTION_REJECT_UNAUTHORIZED: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for tokenType
     */
    static BASE_OPTION_TOKEN_TYPE: ICommandOptionDefinition;
    /**
     * Option used in profile creation and commands for tokenValue to be used to interact with APIs
     */
    static BASE_OPTION_TOKEN_VALUE: ICommandOptionDefinition;
    /**
     * Summary of auth command group
     * @static
     * @memberof AuthConstants
     */
    static readonly AUTH_GROUP_SUMMARY = "Connect to Zowe API ML authentication service";
    /**
     * Description of auth command group
     * @static
     * @memberof AuthConstants
     */
    static readonly AUTH_GROUP_DESCRIPTION: string;
    /**
     * Summary of APIML login command
     * @static
     * @memberof AuthConstants
     */
    static readonly APIML_LOGIN_SUMMARY = "Log in to API ML authentication service";
    /**
     * Description of APIML login command
     * @static
     * @memberof AuthConstants
     */
    static readonly APIML_LOGIN_DESCRIPTION: string;
    /**
     * Example definition for APIML login command
     * @static
     * @memberof AuthConstants
     */
    static readonly APIML_LOGIN_EXAMPLE1: ICommandExampleDefinition;
    /**
     * Example definition for APIML login command with show-token
     * @static
     * @memberof AuthConstants
     */
    static readonly APIML_LOGIN_EXAMPLE2: ICommandExampleDefinition;
    /**
     * Summary of APIML logout command
     * @static
     * @memberof AuthConstants
     */
    static readonly APIML_LOGOUT_SUMMARY = "Log out of API ML authentication service";
    /**
     * Description of APIML logout command
     * @static
     * @memberof AuthConstants
     */
    static readonly APIML_LOGOUT_DESCRIPTION: string;
    /**
     * Example definition for APIML logout command
     * @static
     * @memberof AuthConstants
     */
    static readonly APIML_LOGOUT_EXAMPLE1: ICommandExampleDefinition;
    /**
     * Example definition for APIML logout command with token-value
     * @static
     * @memberof AuthConstants
     */
    static readonly APIML_LOGOUT_EXAMPLE2: ICommandExampleDefinition;
    /**
     * Option used in APIML logout command for token-type
     */
    static APIML_LOGOUT_OPTION_TOKEN_TYPE: ICommandOptionDefinition;
}
